@@ -1,7 +1,10 @@
-context("gmm")
+skip_on_cran()
+
+skip_if_not_installed("modeltests")
+library(modeltests)
 
 skip_if_not_installed("gmm")
-library(gmm)
+suppressPackageStartupMessages(library(gmm))
 
 data(Finance)
 
@@ -24,11 +27,9 @@ test_that("gmm tidier arguments", {
 test_that("tidy.gmm", {
   td <- tidy(fit)
   td2 <- tidy(fit, conf.int = TRUE)
-  tdq <- tidy(fit, quick = TRUE)
-  
+
   check_tidy_output(td)
   check_tidy_output(td2)
-  check_tidy_output(tdq)
 })
 
 test_that("glance.gmm", {
