@@ -1,12 +1,10 @@
-context("lmodel2")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("lmodel2")
-library(lmodel2)
+suppressPackageStartupMessages(library(lmodel2))
 
 data("mod2ex2")
 fit <- lmodel2(Prey ~ Predators, data = mod2ex2, "relative", "relative", 99)
