@@ -1,12 +1,10 @@
-context("robustbase")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("robustbase")
-library(robustbase)
+suppressPackageStartupMessages(library(robustbase))
 
 fit <- lmrob(mpg ~ wt, data = mtcars)
 fit2 <- glmrob(am ~ wt, data = mtcars, family = "binomial")
@@ -45,11 +43,11 @@ test_that("tidy.lmrob", {
 test_that("glance.lmrob", {
   gl <- glance(fit)
   check_glance_outputs(gl)
-  
+
   suppressWarnings(
     gl_rd <- glance(fit_rd)
   )
-  
+
   check_glance_outputs(gl_rd)
 })
 
