@@ -1,10 +1,10 @@
-context("stats-nls")
-
 skip_on_cran()
 
 skip_if_not_installed("modeltests")
 library(modeltests)
 
+skip_if_not_installed("MASS")
+
 fit <- nls(
   wt ~ a + b * mpg + c / disp,
   data = mtcars,
